tfiala updated this revision to Diff 38715.
tfiala added a comment.

Fixed up one missed spot, the python-based class completion script.

I think the original clean build and test run on Linux missed this because I 
don't think we actually use it on Linux.  It's primarily useful on OS X 10.11 
and beyond where we cannot launch inferiors through the shell any longer with 
System Integrity Protection.

In any event, the latest patch fixes up the symbolic link creation within the 
python module directory on non-OS X systems.


http://reviews.llvm.org/D14169

Files:
  lldb.xcodeproj/project.pbxproj
  scripts/Python/finish-swig-Python-LLDB.sh
  scripts/Python/finishSwigPythonLLDB.py
  source/Host/macosx/Host.mm
  source/Host/windows/Host.cpp
  tools/argdumper/CMakeLists.txt

Index: tools/argdumper/CMakeLists.txt
===================================================================
--- tools/argdumper/CMakeLists.txt
+++ tools/argdumper/CMakeLists.txt
@@ -1,8 +1,8 @@
-add_lldb_executable(argdumper
+add_lldb_executable(lldb-argdumper
   argdumper.cpp
   )
 
-target_link_libraries(argdumper liblldb)
+target_link_libraries(lldb-argdumper liblldb)
 
-install(TARGETS argdumper
+install(TARGETS lldb-argdumper
   RUNTIME DESTINATION bin)
Index: source/Host/windows/Host.cpp
===================================================================
--- source/Host/windows/Host.cpp
+++ source/Host/windows/Host.cpp
@@ -230,13 +230,13 @@
         FileSpec expand_tool_spec;
         if (!HostInfo::GetLLDBPath(lldb::ePathTypeSupportExecutableDir, expand_tool_spec))
         {
-            error.SetErrorString("could not find argdumper tool");
+            error.SetErrorString("could not find support executable directory for the lldb-argdumper tool");
             return error;
         }
-        expand_tool_spec.AppendPathComponent("argdumper.exe");
+        expand_tool_spec.AppendPathComponent("lldb-argdumper.exe");
         if (!expand_tool_spec.Exists())
         {
-            error.SetErrorString("could not find argdumper tool");
+            error.SetErrorString("could not find the lldb-argdumper tool");
             return error;
         }
         
@@ -255,7 +255,7 @@
         
         if (status != 0)
         {
-            error.SetErrorStringWithFormat("argdumper exited with error %d", status);
+            error.SetErrorStringWithFormat("lldb-argdumper exited with error %d", status);
             return error;
         }
         
Index: source/Host/macosx/Host.mm
===================================================================
--- source/Host/macosx/Host.mm
+++ source/Host/macosx/Host.mm
@@ -1356,13 +1356,13 @@
         FileSpec expand_tool_spec;
         if (!HostInfo::GetLLDBPath(lldb::ePathTypeSupportExecutableDir, expand_tool_spec))
         {
-            error.SetErrorString("could not get support executable directory for argdumper tool");
+            error.SetErrorString("could not get support executable directory for lldb-argdumper tool");
             return error;
         }
-        expand_tool_spec.AppendPathComponent("argdumper");
+        expand_tool_spec.AppendPathComponent("lldb-argdumper");
         if (!expand_tool_spec.Exists())
         {
-            error.SetErrorStringWithFormat("could not find argdumper tool: %s", expand_tool_spec.GetPath().c_str());
+            error.SetErrorStringWithFormat("could not find the lldb-argdumper tool: %s", expand_tool_spec.GetPath().c_str());
             return error;
         }
 
@@ -1375,7 +1375,7 @@
         
         if (status != 0)
         {
-            error.SetErrorStringWithFormat("argdumper exited with error %d", status);
+            error.SetErrorStringWithFormat("lldb-argdumper exited with error %d", status);
             return error;
         }
         
Index: lldb.xcodeproj/project.pbxproj
===================================================================
--- lldb.xcodeproj/project.pbxproj
+++ lldb.xcodeproj/project.pbxproj
@@ -742,7 +742,7 @@
 		94094C6B163B6F840083A547 /* ValueObjectCast.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 94094C69163B6CD90083A547 /* ValueObjectCast.cpp */; };
 		940B02F619DC96E700AD0F52 /* SBExecutionContext.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 940B02F519DC96E700AD0F52 /* SBExecutionContext.cpp */; };
 		940B04D91A8984FF0045D5F7 /* argdumper.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 940B04D81A8984FF0045D5F7 /* argdumper.cpp */; };
-		940B04E41A8987680045D5F7 /* argdumper in CopyFiles */ = {isa = PBXBuildFile; fileRef = 942829C01A89835300521B30 /* argdumper */; settings = {ATTRIBUTES = (CodeSignOnCopy, ); }; };
+		940B04E41A8987680045D5F7 /* lldb-argdumper in CopyFiles */ = {isa = PBXBuildFile; fileRef = 942829C01A89835300521B30 /* lldb-argdumper */; settings = {ATTRIBUTES = (CodeSignOnCopy, ); }; };
 		94145431175E63B500284436 /* lldb-versioning.h in Headers */ = {isa = PBXBuildFile; fileRef = 94145430175D7FDE00284436 /* lldb-versioning.h */; settings = {ATTRIBUTES = (Public, ); }; };
 		9418EBCD1AA910910058B02E /* VectorType.cpp in Sources */ = {isa = PBXBuildFile; fileRef = 9418EBCC1AA910910058B02E /* VectorType.cpp */; };
 		941BCC7F14E48C4000BB969C /* SBTypeFilter.h in Headers */ = {isa = PBXBuildFile; fileRef = 9461568614E355F2003A195C /* SBTypeFilter.h */; settings = {ATTRIBUTES = (Public, ); }; };
@@ -1081,7 +1081,7 @@
 			dstPath = "";
 			dstSubfolderSpec = 7;
 			files = (
-				940B04E41A8987680045D5F7 /* argdumper in CopyFiles */,
+				940B04E41A8987680045D5F7 /* lldb-argdumper in CopyFiles */,
 			);
 			runOnlyForDeploymentPostprocessing = 0;
 		};
@@ -2484,7 +2484,7 @@
 		942612F61B95000000EF842E /* LanguageCategory.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = LanguageCategory.cpp; path = source/DataFormatters/LanguageCategory.cpp; sourceTree = "<group>"; };
 		942829541A89614000521B30 /* JSON.h */ = {isa = PBXFileReference; lastKnownFileType = sourcecode.c.h; name = JSON.h; path = include/lldb/Utility/JSON.h; sourceTree = "<group>"; };
 		942829551A89614C00521B30 /* JSON.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = JSON.cpp; path = source/Utility/JSON.cpp; sourceTree = "<group>"; };
-		942829C01A89835300521B30 /* argdumper */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = argdumper; sourceTree = BUILT_PRODUCTS_DIR; };
+		942829C01A89835300521B30 /* lldb-argdumper */ = {isa = PBXFileReference; explicitFileType = "compiled.mach-o.executable"; includeInIndex = 0; path = "lldb-argdumper"; sourceTree = BUILT_PRODUCTS_DIR; };
 		94380B8019940B0300BFE4A8 /* StringLexer.h */ = {isa = PBXFileReference; lastKnownFileType = sourcecode.c.h; name = StringLexer.h; path = include/lldb/Utility/StringLexer.h; sourceTree = "<group>"; };
 		94380B8119940B0A00BFE4A8 /* StringLexer.cpp */ = {isa = PBXFileReference; fileEncoding = 4; lastKnownFileType = sourcecode.cpp.cpp; name = StringLexer.cpp; path = source/Utility/StringLexer.cpp; sourceTree = "<group>"; };
 		943B90FC1B991586007BA499 /* VectorIterator.h */ = {isa = PBXFileReference; lastKnownFileType = sourcecode.c.h; name = VectorIterator.h; path = include/lldb/DataFormatters/VectorIterator.h; sourceTree = "<group>"; };
@@ -2968,7 +2968,7 @@
 				26579F68126A25920007C5CB /* darwin-debug */,
 				26DC6A101337FE6900FF7998 /* lldb-server */,
 				2690CD171A6DC0D000E717C8 /* lldb-mi */,
-				942829C01A89835300521B30 /* argdumper */,
+				942829C01A89835300521B30 /* lldb-argdumper */,
 				239504D41BDD451400963CEA /* lldb-gtest */,
 			);
 			name = Products;
@@ -5952,9 +5952,9 @@
 			productReference = 26F5C26A10F3D9A4009D5894 /* lldb */;
 			productType = "com.apple.product-type.tool";
 		};
-		942829BF1A89835300521B30 /* argdumper */ = {
+		942829BF1A89835300521B30 /* lldb-argdumper */ = {
 			isa = PBXNativeTarget;
-			buildConfigurationList = 942829C41A89835400521B30 /* Build configuration list for PBXNativeTarget "argdumper" */;
+			buildConfigurationList = 942829C41A89835400521B30 /* Build configuration list for PBXNativeTarget "lldb-argdumper" */;
 			buildPhases = (
 				942829BC1A89835300521B30 /* Sources */,
 				942829BD1A89835300521B30 /* Frameworks */,
@@ -5966,9 +5966,9 @@
 			dependencies = (
 				942829CA1A89836A00521B30 /* PBXTargetDependency */,
 			);
-			name = argdumper;
+			name = "lldb-argdumper";
 			productName = argdumper;
-			productReference = 942829C01A89835300521B30 /* argdumper */;
+			productReference = 942829C01A89835300521B30 /* lldb-argdumper */;
 			productType = "com.apple.product-type.tool";
 		};
 /* End PBXNativeTarget section */
@@ -6020,7 +6020,7 @@
 				235AFBB5199BC6AD00897A4B /* Linux */,
 				235AFBBB199BC6FD00897A4B /* MacOSX and Linux */,
 				2690CD161A6DC0D000E717C8 /* lldb-mi */,
-				942829BF1A89835300521B30 /* argdumper */,
+				942829BF1A89835300521B30 /* lldb-argdumper */,
 				239504D31BDD451400963CEA /* lldb-gtest */,
 			);
 		};
@@ -7057,7 +7057,7 @@
 		};
 		942829CE1A89842900521B30 /* PBXTargetDependency */ = {
 			isa = PBXTargetDependency;
-			target = 942829BF1A89835300521B30 /* argdumper */;
+			target = 942829BF1A89835300521B30 /* lldb-argdumper */;
 			targetProxy = 942829CD1A89842900521B30 /* PBXContainerItemProxy */;
 		};
 		94E829C9152D33B4006F96A3 /* PBXTargetDependency */ = {
@@ -9516,7 +9516,7 @@
 			defaultConfigurationIsVisible = 0;
 			defaultConfigurationName = BuildAndIntegration;
 		};
-		942829C41A89835400521B30 /* Build configuration list for PBXNativeTarget "argdumper" */ = {
+		942829C41A89835400521B30 /* Build configuration list for PBXNativeTarget "lldb-argdumper" */ = {
 			isa = XCConfigurationList;
 			buildConfigurations = (
 				942829C51A89835400521B30 /* Debug */,
_______________________________________________
lldb-commits mailing list
lldb-commits@lists.llvm.org
http://lists.llvm.org/cgi-bin/mailman/listinfo/lldb-commits

Reply via email to
Index: scripts/Python/finishSwigPythonLLDB.py
===================================================================
--- scripts/Python/finishSwigPythonLLDB.py
+++ scripts/Python/finishSwigPythonLLDB.py
@@ -411,16 +411,16 @@
     return (bOk, strErrMsg);
 
 #++---------------------------------------------------------------------------
 # Details:  Make the symbolic link to the argdumper.
 # Args:     vDictArgs               - (R) Program input parameters.
 #           vstrFrameworkPythonDir  - (R) Python framework directory.
 #           vstrArgdumperFileName   - (R) File name for argdumper.
 # Returns:  Bool - True = function success, False = failure.
 #           Str - Error description on task failure.
 # Throws:   None.
 #--
-def make_symlink_argdumper( vDictArgs, vstrFrameworkPythonDir, vstrArgdumperFileName ):
-    dbg = utilsDebug.CDebugFnVerbose( "Python script make_symlink_argdumper()" );
+def make_symlink_lldb_argdumper( vDictArgs, vstrFrameworkPythonDir, vstrArgdumperFileName ):
+    dbg = utilsDebug.CDebugFnVerbose( "Python script make_symlink_lldb_argdumper()" );
     bOk = True;
     strErrMsg = "";
     strTarget = vstrArgdumperFileName;
@@ -437,7 +437,7 @@
         strExeFileExtn = "";
         if eOSType == utilsOsType.EnumOsType.Windows:
             strExeFileExtn = ".exe";
-        strSrc = os.path.join("bin", "argdumper" + strExeFileExtn);
+        strSrc = os.path.join("bin", "lldb-argdumper" + strExeFileExtn);
 
     bOk, strErrMsg = make_symlink( vDictArgs, vstrFrameworkPythonDir, strSrc, strTarget );
 
@@ -472,10 +472,10 @@
                                                     vstrFrameworkPythonDir,
                                                     strDarwinDebugFileName );
 
-    # Make symlink for argdumper
-    strArgdumperFileName = "argdumper"
+    # Make symlink for lldb-argdumper
+    strArgdumperFileName = "lldb-argdumper"
     if bOk:
-        bOk, strErrMsg = make_symlink_argdumper( vDictArgs,
+        bOk, strErrMsg = make_symlink_lldb_argdumper( vDictArgs,
                                                  vstrFrameworkPythonDir,
                                                  strArgdumperFileName );
 
@@ -411,16 +411,16 @@
 
 #++---------------------------------------------------------------------------
-# Details:  Make the symbolic link to the argdumper.
+# Details:  Make the symbolic link to the lldb-argdumper.
 # Args:     vDictArgs               - (R) Program input parameters.
 #           vstrFrameworkPythonDir  - (R) Python framework directory.
@@ -411,16 +411,16 @@
 # Args:     vDictArgs               - (R) Program input parameters.
 #           vstrFrameworkPythonDir  - (R) Python framework directory.
-#           vstrArgdumperFileName   - (R) File name for argdumper.
+#           vstrArgdumperFileName   - (R) File name for lldb-argdumper.
 # Returns:  Bool - True = function success, False = failure.
 #           Str - Error description on task failure.
Index: scripts/Python/finish-swig-Python-LLDB.sh
===================================================================
--- scripts/Python/finish-swig-Python-LLDB.sh
+++ scripts/Python/finish-swig-Python-LLDB.sh
@@ -188,23 +188,23 @@
     fi
 fi
 
 # Make symlink for argdumper on any platform
 if [ $MakefileCalled -ne 0 ]
 then
     # We are being built by CMake
 
-    if [ ! -L "${framework_python_dir}/argdumper" ]
+    if [ ! -L "${framework_python_dir}/lldb-argdumper" ]
     then
         if [ $Debug -eq 1 ]
         then
-            echo "Creating symlink for argdumper"
+            echo "Creating symlink for lldb-argdumper"
         fi
         cd "${framework_python_dir}"
-        ln -s "../../../../bin/argdumper" argdumper
+        ln -s "../../../../bin/lldb-argdumper" lldb-argdumper
     else
         if [ $Debug -eq 1 ]
         then
-            echo "${framework_python_dir}/argdumper already exists."
+            echo "${framework_python_dir}/lldb-argdumper already exists."
         fi
     fi
 fi
@@ -188,23 +188,23 @@
 fi
 
-# Make symlink for argdumper on any platform
+# Make symlink for lldb-argdumper on any platform
 if [ $MakefileCalled -ne 0 ]
 then